/*
c6x_adc.c
sample application talk-through for 
C6X11 DSK with TI Analog Daughtercard Interface
Michael G. Morrow, 2001
*/       

#include <c6x.h>
#include "c6211dsk.h"

/* declare helper functions */
void Init_McBSP1();
int C62_McBSP_IMH_Bug(); 

int main()
{    
	/* DSP and peripheral initialization */    
	CSR=0x100;			        		/* disable all interrupts            */
  	IER=1;								/* disable all interrupts except NMI */

	/* Set the EMIF up to interface with onboard SDRAM and flash memory. */
	/* EMIF_Init() correctly configures all DSK variants. */
  	EMIF_Init();	
	
	/* Rev 1.X 6211 silicon has the serial ports switched in the high word of the */
	/* interrupt multiplexer.  This code checks for the bug, if it is detected, */
	/* the interrupt assignment is reversed to compensate. */
	if(C62_McBSP_IMH_Bug()) /* is the bug present? */
  		*(unsigned volatile int *)IMH = 0x08203583; /* assign McBSP0 to INT11/12 */
  	else
  		*(unsigned volatile int *)IMH = 0x08203DC3; /* assign McBSP1 to INT11/12 */
	
	/* Configure the serial port to act as the slave on the I2S connection */
	/* with the Analog Daughtercard's PCM3003 codec.  The daughtercard generates */
	/* the bit clock and L/R clock by dividing down the master clock */	
	Init_McBSP1();

 	IER |= 0x1802;                     /* enable McBSP1 Rx/Tx interrupt (11/12) */
  	ICR = 0xffff;                      /* clear all pending interrupts */
  	CSR |= 1;                          /* set GIE to enable interrupt recognition */ 
  	
  	/* the interrupts are now enabled, so the main function is stalled while the */
  	/* interrupt service routines will be invoked automatically to service McBSP1 */
  	/* when data is either received from or must be transmitted to the codec.  */ 
  	while(1) { 
  		;
  	}   
}
 
void Init_McBSP1()
{    
	McBSP *port  = McBSP1_Base;
	
	/* set up McBSP as i2s slave */
	port->spcr = 0;          /* reset port */
	port->pcr  = 0x0000000c; /* fs/clk are inputs */                          
	port->srgr = 0;  		 /* srgr disabled */
	port->rcr  = 0x000400A0; /* 1-phase, 32-bits on rx */
	port->xcr  = 0x000400A0; /* 1-phase, 32-bits on tx */ 
	port->spcr = 0x00010001; /* enable tx/rx */
	port->dxr  = 0;      	 /* perform dummy write to start tx isr */
}


int C62_McBSP_IMH_Bug() /* check for IMH bug in Rev 1.X silicon where */
{   					/* McBSP0 and McBSP1 are switched in the interrupt mux */           
	McBSP *port0  = McBSP0_Base, *port1  = McBSP1_Base; 
	volatile int i;
	
  	IER=1;                  /* disable all interrupts except NMI */
  	*(unsigned volatile int *)IMH = 0x08203DC3; /* assign McBSP1 Tx/Rx to INT11/12 */
 	ICR=0xffff;             /* clear all pending interrupts      */
 	port1->spcr = 0; 		/* reset McBSP1 */
 	port0->spcr = 0; 		/* reset McBSP0 */
 	ICR=0xffff;             /* clear all pending interrupts      */
	port0->spcr = 0x312031; /* set McBSP0 to irq on sync error */
	port0->spcr = 0x392039; /* force McBSP0 rx/tx sync error */

	i = 20;	                /* delay for irq recognition */
	while(i--)
		;
     
    /* check to see where irq was routed to identify if bug is present */
	if((IFR & 0x1800) == 0x1800) /* IFR was set by McBSP1, so is Rev 1.X silicon */
		return 1;
	return 0;
}
