/*
isrs.c
sample talk-through application for 
C6X11 DSK with TI Analog Daughtercard Interface  
Michael G. Morrow, 2001
*/

#include "c6211dsk.h"

#define LEFT  0
#define RIGHT 1
/* Data is received from the PCM3003 codec as 2 16-bit words (left/right)   */
/* packed into one 32-bit word.  This  union allows the data to be accessed */
/* as a single entitiy when transferring to and from the serial port, but   */
/* still be able to manipulate the left and right channels independently.   */
volatile union {
	unsigned int uint;
	short channel[2];
	} CodecData;    

interrupt void McBSP1_Rx_ISR()
{                              
	McBSP *port  = McBSP1_Base;
	short temp; 
	
	CodecData.uint = port->drr; /* get data from McBSP1 */
	
	/* As a demonstration of using the individual channel data, */
	/* put L+R on R channel and L-R on L channel.  Uncomment */
	/* the next 3 lines to include the code. */
	temp = CodecData.channel[RIGHT];  /* save R channel data */
	CodecData.channel[RIGHT] += CodecData.channel[LEFT]; /* R <- L+R */
	CodecData.channel[LEFT] -= temp; /* L <- L-R */  
	/* Processed channel data will be sent back to the codec by */
	/* the transmit ISR (McBSP1_Tx_ISR) */
}

interrupt void McBSP1_Tx_ISR()
{
	McBSP *port  = McBSP1_Base;

	port->dxr = CodecData.uint; /* send data to McBSP1 */  
}

